#
# spec file for package v4l2loopback
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%if 0%{?suse_version} < 1550 && 0%{?sle_version} <= 150300
# systemd-rpm-macros is wrong in 15.3 and below
%define _modprobedir /lib/modprobe.d
%endif
%global modprobe_d_files 98-v4l2loopback.conf
%{!?_modulesloaddir: %define _modulesloaddir /usr/lib/modules-load.d/}

Name:           v4l2loopback
Version:        0.12.7
Release:        lp156.1.6
Summary:        A kernel module to create V4L2 loopback devices
License:        GPL-2.0-or-later
URL:            https://github.com/umlaeute/v4l2loopback
Source:         https://github.com/umlaeute/v4l2loopback/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        preamble
Source2:        modprobe.d_98-v4l2loopback.conf
Source3:        modules-load.d_v4l2loopback.conf
# PATCH-FIX-OPENSUSE v4l2loopback-include_header.patch
Patch0:         v4l2loopback-include_header.patch
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  help2man

%if 0%{?is_opensuse}
%kernel_module_package -p %{_sourcedir}/preamble
%else
%kernel_module_package -c %_sourcedir/_projectcert.crt -p %{_sourcedir}/preamble
%endif

%description
This module allows you to create "virtual video devices". Normal (v4l2)
applications will read these devices as if they were ordinary video
devices, but the video will not be read from e.g. a capture card but
instead it is generated by another application.

%package autoload
Summary:        Autoload driver for V4L2 loopback devices
Supplements:    kmod(v4l2loopback.ko)
BuildArch:      noarch
Requires:       systemd

%description autoload
Configuration files to autoload the module during system startup.

%package utils
Summary:        Utils for V4L2 loopback devices
Requires:       v4l-utils
Recommends:     gstreamer:/usr/bin/gst-launch-1.0
Supplements:    kmod(v4l2loopback.ko)
BuildArch:      noarch

%description utils
v4l2loopback-ctl for controlling FPS, placeholder image and image format.

%prep
%autosetup
set -- *
mkdir source
mv "$@" source/
mkdir obj

%build
for flavor in %{flavors_to_build}; do
	rm -rf obj/$flavor
	cp -r source obj/$flavor
	make V=1 %{?_smp_mflags} -C %{kernel_source $flavor} %{?linux_make_arch} modules M=$PWD/obj/$flavor
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR='%{kernel_module_package_moddir}'
for flavor in %{flavors_to_build}; do
	make V=1 -C %{kernel_source $flavor} modules_install M=$PWD/obj/$flavor
	make V=1 -C obj/$flavor install-utils DESTDIR=%{?buildroot:%{buildroot}} PREFIX=%{_prefix}
	make V=1 -C obj/$flavor install-man DESTDIR=%{?buildroot:%{buildroot}} PREFIX=%{_prefix}
done

export BRP_PESIGN_FILES='*.ko'

install -D -m 0644 %{SOURCE2} %{buildroot}%{_modprobedir}/98-v4l2loopback.conf
install -D -m 0644 %{SOURCE3} %{buildroot}%{_modulesloaddir}/v4l2loopback.conf

%pre
# Avoid restoring outdated stuff in posttrans
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -f "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}.rpmsave.old" || :
done

%posttrans
# Migration of modprobe.conf files to _modprobedir
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -fv "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}" || :
done

%files utils
%attr(0755,root,root) %{_bindir}/v4l2loopback-ctl
%attr(0644,root,root) %{_mandir}/man1/v4l2loopback-ctl.1.gz

%files autoload
%dir %{_modprobedir}
%{_modprobedir}/98-v4l2loopback.conf
%dir %{_modulesloaddir}
%{_modulesloaddir}/v4l2loopback.conf

%changelog
* Thu Sep 29 2022 Stanislav Brabec <sbrabec@suse.com>
- Update to version 0.12.7:
  * Add explicit format specifier to printf() invocations
    (bsc#1202156, CVE-2022-2652).
  * REMAKE_INITRD is deprecated in dkms 3
  * event: install event (un)subscribe hook
  * Don't fail if allocating 0-sized buffers
  * Other minor fixes
- Refresh v4l2loopback-include_header.patch.
* Fri Mar  4 2022 Martin Wilck <mwilck@suse.com>
- Fix modprobe.d location for 15.3 and earlier (bsc#1196275, jsc#SLE-20639)
* Tue Feb  9 2021 Frederic Crozat <fcrozat@suse.com>
- Add undefined macros when building on older distributions
* Tue Feb  2 2021 Frederic Crozat <fcrozat@suse.com>
- Add Secureboot signing support
* Wed Dec 16 2020 Marcus Rueckert <mrueckert@suse.de>
- add -autoload subpackages that provides the configuration files
  to autoload the driver on startup
* Fri Jul 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fixup util dependencies: pull in required vl42-ctl for
  v4l2loopback-ctl, recommend gst-launch, supplement kernel
  module (v4l2loopback.ko).
- Make util package noarch, its just a shell script.
* Sun Apr 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.5
  * Fix build in Linux 5.7-rc1 due to symbol name changes
  * Simplify set/clear of V4L2_CAP_DEVICE_CAPS in querycaps
  * Use temp-var for capabilities
  * Also set vdev->device_caps
* Thu Apr  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.4
  * Explain what exclusive_caps does instead of referring to a
    closed ticket
  * Use "Chrome" rather than "Chromium"
  * Mention exclusive_caps mode option
  * Add linebreaks to fix markdown
  * Set the default number of buffers to 2
  * instruction on obtaining yuv files
  * infinite loop over yuv frames
  * Drop cast to (time_t)
  * print "SUCCESS" message on installation success
  * use v4l2_buffer ptr instead of timeval
- Dropped v4l2loopback-dont_use_timeval.patch and
  v4l2loopback-drop_cast_to_time_t.patch (merged upstream)
* Tue Feb 25 2020 aloisio@gmx.com
- Added v4l2loopback-dont_use_timeval.patch and
  v4l2loopback-drop_cast_to_time_t.patch (fix boo#1164757)
* Wed Jan  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Made build verbose
- Removed Group and superfluous build requirements
- Added v4l2loopback-include_header.patch (fixes boo#1159777)
* Sat Dec  7 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.3
  * v4l2lookback: Port to kernel 5.4+
  * Set video_device->device_caps for linux>4.7.0
  * Set some more device_caps
  * Update issue templates
* Mon May 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.2
  * Fixed compat with kernel 5.0
  * Replace v4l2_get_timestamp with ktime_get_ts(64) for
    linux-5.1 compat
- Dropped v4l2loopback-no_deprecated_function.patch (merged
  upstream)
* Thu May 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Added v4l2loopback-no_deprecated_function.patch (fix build with
  newer kernels)
* Wed Jan 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.1
  [ IOhannes m zmölnig ]
  * Fix permission of source code files
  * Initialize variables
  * Use %%u to print size_t
  * Improve coding style by removing unused variables
  * More coding style fixes
  * Use GStreamer-1.0 caps in the documentation
  * Gst1.0 compat for example-script
  * Protect VP9 and HEVC by #ifdef guards
  [ Andrii Danyleiko ]
  * Fix typo
  [ Kai Kang ]
  * Replace do_gettimeofday with v4l2_get_timestamp for linux-5
    compat
* Mon Jul  2 2018 aloisio@gmx.com
- Update to version 0.12.0
  * Fixed compat with kernel 4.16
  * NV12 support
  * 8bit Bayer support
* Mon Jun 25 2018 aloisio@gmx.com
- Use %%{?linux_make_arch} when building kernel modules
  (boo#1098050).
* Tue Apr  3 2018 guillaume.gardet@opensuse.org
- Update to 0.11.0:
  * Adapted to new kernel timer API
  * VP9 & HEVC support
  * Hacks to work around issues with Google Chrome and GStreamer-0.10
* Fri Aug 11 2017 aloisio@gmx.com
- Added v4l-utils as runtime dependency
* Sat Jul 29 2017 aloisio@gmx.com
- Added preamble as source
* Fri Jul 28 2017 aloisio@gmx.com
- Update to 0.10.0
* Fri Jan 17 2014 matwey.kornilov@gmail.com
- Update to 0.8.0
* Sun Feb 17 2013 matwey.kornilov@gmail.com
- Initial commit (0.6.3)
